import { GraphQLNamedType } from "graphql";
import { MetadataStorage } from "./MetadataStorage";
import { DefinitionClass } from "../types";
import { ASTParser } from "../sdl/ast";
export interface DefinitionMetadataConfig {
    typeName?: string;
    description?: string;
    directives?: any;
}
/**
 * Contain configs required to build named GraphQL types.
 * Guarantee its type instance only created once.
 */
export declare class DefinitionMetadata<TConfig extends DefinitionMetadataConfig = DefinitionMetadataConfig> {
    static define(astParser: ASTParser, storage?: MetadataStorage): (definitionClass: DefinitionClass<any>) => void;
    protected static decorate(astParser: ASTParser, storage: MetadataStorage, definitionClass: DefinitionClass): void;
    protected readonly config: TConfig;
    constructor(config: TConfig);
    readonly typeName: string;
    readonly description: string | undefined;
    /**
     * Build GraphQLType instance from metadata.
     */
    buildTypeInstance(storage: MetadataStorage, definitionClass: DefinitionClass): GraphQLNamedType;
}
