"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Contain configs required to build named GraphQL types.
 * Guarantee its type instance only created once.
 */
var DefinitionMetadata = /** @class */ (function () {
    function DefinitionMetadata(config) {
        this.config = config;
    }
    DefinitionMetadata.define = function (astParser, storage) {
        var _this = this;
        var targetStorage = storage || require('../globalMetadataStorage').globalMetadataStorage;
        return function (definitionClass) { return _this.decorate(astParser, targetStorage, definitionClass); };
    };
    DefinitionMetadata.decorate = function (astParser, storage, definitionClass) {
        throw new Error('Not implemented');
    };
    Object.defineProperty(DefinitionMetadata.prototype, "typeName", {
        get: function () {
            var typeName = this.config.typeName;
            if (!typeName) {
                throw new Error('Should have typeName');
            }
            return typeName;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DefinitionMetadata.prototype, "description", {
        get: function () {
            return this.config.description;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * Build GraphQLType instance from metadata.
     */
    DefinitionMetadata.prototype.buildTypeInstance = function (storage, definitionClass) {
        throw new Error("Should implement typeInstance getter in " + this.constructor.name);
    };
    ;
    return DefinitionMetadata;
}());
exports.DefinitionMetadata = DefinitionMetadata;
//# sourceMappingURL=DefinitionMetadata.js.map