import { DefinitionClass } from '../types';
import { DefinitionMetadata } from './DefinitionMetadata';
import { GraphQLNamedType } from 'graphql';
import { FieldReference } from '../field/Field';
import { InputFieldReference } from '../field/InputField';
export interface DefinitionMetadataEntry<T extends DefinitionMetadata = DefinitionMetadata> {
    definitionClass: DefinitionClass;
    metadata: T;
}
export interface FieldReferenceEntry {
    definitionClass: DefinitionClass;
    reference: FieldReference;
}
export interface InputFieldReferenceEntry {
    definitionClass: DefinitionClass;
    reference: InputFieldReference;
}
/**
 * Keep all [[DefinitionMetadata]] and [[GenericMetadata]].
 * Provide methods to query metadata with its associated class or graphql type name.
 */
export declare class MetadataStorage {
    readonly definitionMetadata: Array<DefinitionMetadataEntry<DefinitionMetadata>>;
    readonly memoizedTypeInstanceMap: Map<DefinitionClass, GraphQLNamedType>;
    readonly fieldReferences: Array<FieldReferenceEntry>;
    readonly inputFieldReferences: Array<InputFieldReferenceEntry>;
    /**
     * Add a new [[Metadata]] object to storage.
     * @param metadata A metadata object to register
     */
    register(metadata: DefinitionMetadata<any>, definitionClass: DefinitionClass): void;
    registerFieldReference(reference: FieldReference, definitionClass: DefinitionClass): void;
    registerInputFieldReference(reference: InputFieldReference, definitionClass: DefinitionClass): void;
    /**
     * Get a [[DefinitionMetadata]] object which is instance of the `metadataClass` and associated to `definitionClass`
     * @param metadataClass A [[DefinitionMetadata]] subclass to query
     * @param definitionClass A class associated with metadata to query
     */
    getDefinitionMetadata<T extends DefinitionMetadata>(metadataClass: {
        new (...args: any[]): T;
    }, definitionClass: Function): DefinitionMetadataEntry<T>;
    /**
     * Get a [[DefinitionMetadata]] object by the name of the GraphQLType that the metadata will generate.
     * @param name The name of a GraphQLType which will be built from metadata to query
     */
    getDefinitionMetadataByName(name: string): DefinitionMetadataEntry<any>;
    queryFieldReferences(definitionClass: Function): FieldReferenceEntry[];
    queryInputFieldReference(definitionClass: Function): InputFieldReferenceEntry[];
}
