import { GraphQLObjectType, GraphQLFieldConfigMap, GraphQLInterfaceType, GraphQLFieldConfig } from "graphql";
import { DefinitionMetadata, DefinitionMetadataConfig } from "../base/DefinitionMetadata";
import { MetadataStorage, FieldReferenceEntry } from "../base/MetadataStorage";
import { TypeExpression } from "../type-expression/TypeExpression";
import { DefinitionClass } from "../types";
import { ASTParser } from "../sdl/ast";
export interface ObjectTypeConfig extends DefinitionMetadataConfig {
    description?: string;
    interfaces?: TypeExpression[];
}
/**
 * Metadata type for ObjectType
 */
export declare class ObjectType<TConfig extends ObjectTypeConfig = ObjectTypeConfig> extends DefinitionMetadata<TConfig> {
    protected static decorate(astParser: ASTParser, storage: MetadataStorage, definitionClass: DefinitionClass): void;
    buildFieldConfig(storage: MetadataStorage, definitionClass: DefinitionClass, entry: FieldReferenceEntry): GraphQLFieldConfig<any, any>;
    buildFieldConfigMap(storage: MetadataStorage, definitionClass: DefinitionClass): GraphQLFieldConfigMap<any, any>;
    /**
     * Build GraphQLObjectType instance from metadata.
     */
    buildTypeInstance(storage: MetadataStorage, definitionClass: DefinitionClass): GraphQLObjectType;
    findInterfaces(storage: MetadataStorage): GraphQLInterfaceType[] | undefined;
    buildIsTypeOf(storage: MetadataStorage, definitionClass: DefinitionClass): (source: any) => boolean;
}
