"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var graphql_1 = require("graphql");
var DefinitionMetadata_1 = require("../base/DefinitionMetadata");
/**
 * Metadata type for ObjectType
 */
var ObjectType = /** @class */ (function (_super) {
    __extends(ObjectType, _super);
    function ObjectType() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ObjectType.decorate = function (astParser, storage, definitionClass) {
        var _this = this;
        astParser.objectTypeMetadataConfigs.forEach(function (config) {
            storage.register(new _this(config), definitionClass);
        });
        astParser.fieldMetadataConfigs.forEach(function (config) {
            storage.registerFieldReference(config, definitionClass);
        });
    };
    ObjectType.prototype.buildFieldConfig = function (storage, definitionClass, entry) {
        var name = entry.reference.name;
        var config = Object.assign({}, entry.reference.field.buildConfig(storage), entry.reference.props);
        if (definitionClass[name] instanceof Function) {
            config.resolve = definitionClass[name];
        }
        return config;
    };
    ObjectType.prototype.buildFieldConfigMap = function (storage, definitionClass) {
        var _this = this;
        var refs = storage.queryFieldReferences(definitionClass);
        return (refs.reduce(function (results, entry) {
            results[entry.reference.name] = _this.buildFieldConfig(storage, definitionClass, entry);
            return results;
        }, {}));
    };
    /**
     * Build GraphQLObjectType instance from metadata.
     */
    ObjectType.prototype.buildTypeInstance = function (storage, definitionClass) {
        var name = this.typeName;
        var fields = this.buildFieldConfigMap.bind(this, storage, definitionClass);
        var interfaces = this.findInterfaces(storage);
        var description = this.description;
        var isTypeOf = this.buildIsTypeOf(storage, definitionClass);
        return new graphql_1.GraphQLObjectType({ name: name, fields: fields, interfaces: interfaces, description: description, isTypeOf: isTypeOf });
    };
    ObjectType.prototype.findInterfaces = function (storage) {
        var interfaces = this.config.interfaces;
        return interfaces && interfaces.map(function (i) { return i.buildTypeInstance(storage); });
    };
    ObjectType.prototype.buildIsTypeOf = function (storage, definitionClass) {
        return function (source) { return (source instanceof definitionClass); };
    };
    return ObjectType;
}(DefinitionMetadata_1.DefinitionMetadata));
exports.ObjectType = ObjectType;
//# sourceMappingURL=ObjectType.js.map