"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var graphql_1 = require("graphql");
var types_1 = require("../types");
var DefinitionMetadata_1 = require("../base/DefinitionMetadata");
var formatObjectInfo_1 = require("../utilities/formatObjectInfo");
/**
 * Contain an argument which can be resolved to GraphQLType instance.
 */
var TypeExpression = /** @class */ (function () {
    function TypeExpression(typeArg) {
        this.typeArg = typeArg;
    }
    TypeExpression.prototype.getCompleteTypeArg = function () {
        var typeArg = this.typeArg;
        return types_1.isLazy(typeArg) ? typeArg() : typeArg;
    };
    TypeExpression.prototype.getDefinitionMetadataEntry = function (storage) {
        var completeTypeArg = this.getCompleteTypeArg();
        if (completeTypeArg instanceof Function) {
            return storage.getDefinitionMetadata(DefinitionMetadata_1.DefinitionMetadata, completeTypeArg);
        }
        else if (typeof completeTypeArg === 'string') {
            return storage.getDefinitionMetadataByName(completeTypeArg);
        }
        else {
            throw new Error("Cannot find any DefinitionMetadata with TypeExpression of " + formatObjectInfo_1.formatObjectInfo(completeTypeArg));
        }
    };
    TypeExpression.prototype.buildTypeInstance = function (storage) {
        var completeTypeArg = this.getCompleteTypeArg();
        if (graphql_1.isType(completeTypeArg)) {
            return completeTypeArg;
        }
        var entry = this.getDefinitionMetadataEntry(storage);
        var typeInstance = storage.memoizedTypeInstanceMap.get(entry.definitionClass);
        if (!typeInstance) {
            var typeMetadata = storage.getDefinitionMetadata(DefinitionMetadata_1.DefinitionMetadata, entry.definitionClass);
            if (!typeMetadata) {
                throw new Error("Given class " + entry.definitionClass.name + " has no corresponding metadata");
            }
            typeInstance = typeMetadata.metadata.buildTypeInstance(storage, entry.definitionClass);
            storage.memoizedTypeInstanceMap.set(entry.definitionClass, typeInstance);
        }
        return typeInstance;
    };
    return TypeExpression;
}());
exports.TypeExpression = TypeExpression;
//# sourceMappingURL=TypeExpression.js.map